@@ -40,18 +40,18 @@ class Layer1(AWSQueryConnection):
                  proxy=None, proxy_port=None,
                  proxy_user=None, proxy_pass=None, debug=0,
                  https_connection_factory=None, region=None, path='/',
-                 api_version=None, security_token=None):
+                 api_version=None, security_token=None, profile_name=None):
         if not region:
             region = RegionInfo(self, self.DefaultRegionName,
                                 self.DefaultRegionEndpoint)
         self.region = region
-        AWSQueryConnection.__init__(self, aws_access_key_id,
+        super(Layer1, self).__init__(aws_access_key_id,
                                     aws_secret_access_key,
                                     is_secure, port, proxy, proxy_port,
                                     proxy_user, proxy_pass,
                                     self.region.endpoint, debug,
                                     https_connection_factory, path,
-                                    security_token)
+                                    security_token, profile_name=profile_name)
 
     def _required_auth_capability(self):
         return ['hmac-v4']
@@ -237,7 +237,8 @@ class Layer1(AWSQueryConnection):
                            version_label=None, template_name=None,
                            solution_stack_name=None, cname_prefix=None,
                            description=None, option_settings=None,
-                           options_to_remove=None):
+                           options_to_remove=None, tier_name=None,
+                           tier_type=None, tier_version='1.0'):
         """Launches an environment for the application using a configuration.
 
         :type application_name: string
@@ -308,6 +309,25 @@ class Layer1(AWSQueryConnection):
             options to remove from the configuration set for this new
             environment.
 
+        :type tier_name: string
+        :param tier_name: The name of the tier.  Valid values are
+            "WebServer" and "Worker". Defaults to "WebServer".
+            The ``tier_name`` and a ``tier_type`` parameters are
+            related and the values provided must be valid.
+            The possible combinations are:
+
+              * "WebServer" and "Standard" (the default)
+              * "Worker" and "SQS/HTTP"
+
+        :type tier_type: string
+        :param tier_type: The type of the tier.  Valid values are
+            "Standard" if ``tier_name`` is "WebServer" and "SQS/HTTP"
+            if ``tier_name`` is "Worker". Defaults to "Standard".
+
+        :type tier_version: string
+        :type tier_version: The version of the tier.  Valid values
+            currently are "1.0". Defaults to "1.0".
+
         :raises: TooManyEnvironmentsException, InsufficientPrivilegesException
 
         """
@@ -330,6 +350,10 @@ class Layer1(AWSQueryConnection):
         if options_to_remove:
             self.build_list_params(params, options_to_remove,
                                    'OptionsToRemove.member')
+        if tier_name and tier_type and tier_version:
+            params['Tier.member.Name'] = tier_name
+            params['Tier.member.Type'] = tier_type
+            params['Tier.member.Version'] = tier_version
         return self._get_response('CreateEnvironment', params)
 
     def create_storage_location(self):
@@ -848,9 +872,9 @@ class Layer1(AWSQueryConnection):
         return self._get_response('RetrieveEnvironmentInfo', params)
 
     def swap_environment_cnames(self, source_environment_id=None,
-                                 source_environment_name=None,
-                                 destination_environment_id=None,
-                                 destination_environment_name=None):
+                                source_environment_name=None,
+                                destination_environment_id=None,
+                                destination_environment_name=None):
         """Swaps the CNAMEs of two environments.
 
         :type source_environment_id: string
@@ -1021,7 +1045,8 @@ class Layer1(AWSQueryConnection):
     def update_environment(self, environment_id=None, environment_name=None,
                            version_label=None, template_name=None,
                            description=None, option_settings=None,
-                           options_to_remove=None):
+                           options_to_remove=None, tier_name=None,
+                           tier_type=None, tier_version='1.0'):
         """
         Updates the environment description, deploys a new application
         version, updates the configuration settings to an entirely new
@@ -1073,6 +1098,25 @@ class Layer1(AWSQueryConnection):
         :param options_to_remove: A list of custom user-defined configuration
             options to remove from the configuration set for this environment.
 
+        :type tier_name: string
+        :param tier_name: The name of the tier.  Valid values are
+            "WebServer" and "Worker". Defaults to "WebServer".
+            The ``tier_name`` and a ``tier_type`` parameters are
+            related and the values provided must be valid.
+            The possible combinations are:
+
+              * "WebServer" and "Standard" (the default)
+              * "Worker" and "SQS/HTTP"
+
+        :type tier_type: string
+        :param tier_type: The type of the tier.  Valid values are
+            "Standard" if ``tier_name`` is "WebServer" and "SQS/HTTP"
+            if ``tier_name`` is "Worker". Defaults to "Standard".
+
+        :type tier_version: string
+        :type tier_version: The version of the tier.  Valid values
+            currently are "1.0". Defaults to "1.0".
+
         :raises: InsufficientPrivilegesException
         """
         params = {}
@@ -1093,6 +1137,10 @@ class Layer1(AWSQueryConnection):
         if options_to_remove:
             self.build_list_params(params, options_to_remove,
                                    'OptionsToRemove.member')
+        if tier_name and tier_type and tier_version:
+            params['Tier.member.Name'] = tier_name
+            params['Tier.member.Type'] = tier_type
+            params['Tier.member.Version'] = tier_version
         return self._get_response('UpdateEnvironment', params)
 
     def validate_configuration_settings(self, application_name,
