@@ -79,7 +79,7 @@ class DirectConnectConnection(AWSQueryConnection):
         if 'host' not in kwargs:
             kwargs['host'] = region.endpoint
 
-        AWSQueryConnection.__init__(self, **kwargs)
+        super(DirectConnectConnection, self).__init__(**kwargs)
         self.region = region
 
     def _required_auth_capability(self):
