@@ -186,7 +186,7 @@ class LoadBalancer(object):
         :param zones: The name of the zone(s) to add.
 
         """
-        if isinstance(zones, str) or isinstance(zones, unicode):
+        if isinstance(zones, basestring):
             zones = [zones]
         new_zones = self.connection.enable_availability_zones(self.name, zones)
         self.availability_zones = new_zones
@@ -199,7 +199,7 @@ class LoadBalancer(object):
         :param zones: The name of the zone(s) to add.
 
         """
-        if isinstance(zones, str) or isinstance(zones, unicode):
+        if isinstance(zones, basestring):
             zones = [zones]
         new_zones = self.connection.disable_availability_zones(self.name, zones)
         self.availability_zones = new_zones
@@ -266,7 +266,7 @@ class LoadBalancer(object):
             to add to this load balancer.
 
         """
-        if isinstance(instances, str) or isinstance(instances, unicode):
+        if isinstance(instances, basestring):
             instances = [instances]
         new_instances = self.connection.register_instances(self.name,
                                                            instances)
@@ -281,7 +281,7 @@ class LoadBalancer(object):
             to remove from this load balancer.
 
         """
-        if isinstance(instances, str) or isinstance(instances, unicode):
+        if isinstance(instances, basestring):
             instances = [instances]
         new_instances = self.connection.deregister_instances(self.name,
                                                              instances)
@@ -324,7 +324,7 @@ class LoadBalancer(object):
                                                               listeners)
 
     def create_listener(self, inPort, outPort=None, proto="tcp"):
-        if outPort == None:
+        if outPort is None:
             outPort = inPort
         return self.create_listeners([(inPort, outPort, proto)])
 
@@ -380,7 +380,7 @@ class LoadBalancer(object):
         :param subnets: The name of the subnet(s) to add.
 
         """
-        if isinstance(subnets, str) or isinstance(subnets, unicode):
+        if isinstance(subnets, basestring):
             subnets = [subnets]
         new_subnets = self.connection.attach_lb_to_subnets(self.name, subnets)
         self.subnets = new_subnets
@@ -393,7 +393,7 @@ class LoadBalancer(object):
         :param subnets: The name of the subnet(s) to detach.
 
         """
-        if isinstance(subnets, str) or isinstance(subnets, unicode):
+        if isinstance(subnets, basestring):
             subnets = [subnets]
         new_subnets = self.connection.detach_lb_from_subnets(self.name, subnets)
         self.subnets = new_subnets
@@ -408,8 +408,7 @@ class LoadBalancer(object):
         :param security_groups: The name of the security group(s) to add.
 
         """
-        if isinstance(security_groups, str) or \
-              isinstance(security_groups, unicode):
+        if isinstance(security_groups, basestring):
             security_groups = [security_groups]
         new_sgs = self.connection.apply_security_groups_to_lb(
                                          self.name, security_groups)
