@@ -99,7 +99,7 @@ class NetworkInterface(TaggedEC2Object):
     """
 
     def __init__(self, connection=None):
-        TaggedEC2Object.__init__(self, connection)
+        super(NetworkInterface, self).__init__(connection)
         self.id = None
         self.subnet_id = None
         self.vpc_id = None
@@ -119,7 +119,8 @@ class NetworkInterface(TaggedEC2Object):
         return 'NetworkInterface:%s' % self.id
 
     def startElement(self, name, attrs, connection):
-        retval = TaggedEC2Object.startElement(self, name, attrs, connection)
+        retval = super(NetworkInterface, self).startElement(name, attrs,
+            connection)
         if retval is not None:
             return retval
         if name == 'groupSet':
