@@ -27,7 +27,7 @@ from boto.exception import BotoClientError
 class PlacementGroup(EC2Object):
 
     def __init__(self, connection=None, name=None, strategy=None, state=None):
-        EC2Object.__init__(self, connection)
+        super(PlacementGroup, self).__init__(connection)
         self.name = name
         self.strategy = strategy
         self.state = state
