@@ -57,6 +57,7 @@ STORAGE_CLASS_HEADER_KEY = 'storage-class'
 MFA_HEADER_KEY = 'mfa-header'
 SERVER_SIDE_ENCRYPTION_KEY = 'server-side-encryption-header'
 VERSION_ID_HEADER_KEY = 'version-id-header'
+RESTORE_HEADER_KEY = 'restore-header'
 
 STORAGE_COPY_ERROR = 'StorageCopyError'
 STORAGE_CREATE_ERROR = 'StorageCreateError'
@@ -68,8 +69,10 @@ STORAGE_RESPONSE_ERROR = 'StorageResponseError'
 class Provider(object):
 
     CredentialMap = {
-        'aws':    ('aws_access_key_id', 'aws_secret_access_key'),
-        'google': ('gs_access_key_id',  'gs_secret_access_key'),
+        'aws':    ('aws_access_key_id', 'aws_secret_access_key',
+                   'aws_security_token'),
+        'google': ('gs_access_key_id',  'gs_secret_access_key',
+                   None),
     }
 
     AclClassMap = {
@@ -122,6 +125,7 @@ class Provider(object):
             VERSION_ID_HEADER_KEY: AWS_HEADER_PREFIX + 'version-id',
             STORAGE_CLASS_HEADER_KEY: AWS_HEADER_PREFIX + 'storage-class',
             MFA_HEADER_KEY: AWS_HEADER_PREFIX + 'mfa',
+            RESTORE_HEADER_KEY: AWS_HEADER_PREFIX + 'restore',
         },
         'google': {
             HEADER_PREFIX_KEY: GOOG_HEADER_PREFIX,
@@ -144,6 +148,7 @@ class Provider(object):
             VERSION_ID_HEADER_KEY: GOOG_HEADER_PREFIX + 'version-id',
             STORAGE_CLASS_HEADER_KEY: None,
             MFA_HEADER_KEY: None,
+            RESTORE_HEADER_KEY: None,
         }
     }
 
@@ -165,18 +170,19 @@ class Provider(object):
     }
 
     def __init__(self, name, access_key=None, secret_key=None,
-                 security_token=None):
+                 security_token=None, profile_name=None):
         self.host = None
         self.port = None
         self.host_header = None
         self.access_key = access_key
         self.secret_key = secret_key
         self.security_token = security_token
+        self.profile_name = profile_name
         self.name = name
         self.acl_class = self.AclClassMap[self.name]
         self.canned_acls = self.CannedAclsMap[self.name]
         self._credential_expiry_time = None
-        self.get_credentials(access_key, secret_key)
+        self.get_credentials(access_key, secret_key, security_token, profile_name)
         self.configure_headers()
         self.configure_errors()
         # Allow config file to override default host and port.
@@ -239,14 +245,18 @@ class Provider(object):
             else:
                 return False
 
-    def get_credentials(self, access_key=None, secret_key=None):
-        access_key_name, secret_key_name = self.CredentialMap[self.name]
+    def get_credentials(self, access_key=None, secret_key=None,
+                        security_token=None, profile_name=None):
+        access_key_name, secret_key_name, security_token_name = self.CredentialMap[self.name]
         if access_key is not None:
             self.access_key = access_key
             boto.log.debug("Using access key provided by client.")
         elif access_key_name.upper() in os.environ:
             self.access_key = os.environ[access_key_name.upper()]
             boto.log.debug("Using access key found in environment variable.")
+        elif config.has_option("profile %s" % profile_name, access_key_name):
+            self.access_key = config.get("profile %s" % profile_name, access_key_name)
+            boto.log.debug("Using access key found in config file: profile %s." % profile_name)
         elif config.has_option('Credentials', access_key_name):
             self.access_key = config.get('Credentials', access_key_name)
             boto.log.debug("Using access key found in config file.")
@@ -257,6 +267,9 @@ class Provider(object):
         elif secret_key_name.upper() in os.environ:
             self.secret_key = os.environ[secret_key_name.upper()]
             boto.log.debug("Using secret key found in environment variable.")
+        elif config.has_option("profile %s" % profile_name, secret_key_name):
+            self.secret_key = config.get("profile %s" % profile_name, secret_key_name)
+            boto.log.debug("Using secret key found in config file: profile %s." % profile_name)
         elif config.has_option('Credentials', secret_key_name):
             self.secret_key = config.get('Credentials', secret_key_name)
             boto.log.debug("Using secret key found in config file.")
@@ -273,6 +286,19 @@ class Provider(object):
                 keyring_name, self.access_key)
             boto.log.debug("Using secret key found in keyring.")
 
+        if security_token is not None:
+            self.security_token = security_token
+            boto.log.debug("Using security token provided by client.")
+        elif security_token_name is not None:
+            if security_token_name.upper() in os.environ:
+                self.security_token = os.environ[security_token_name.upper()]
+                boto.log.debug("Using security token found in environment"
+                               " variable.")
+            elif config.has_option('Credentials', security_token_name):
+                self.security_token = config.get('Credentials',
+                                                 security_token_name)
+                boto.log.debug("Using security token found in config file.")
+
         if ((self._access_key is None or self._secret_key is None) and
                 self.MetadataServiceSupport[self.name]):
             self._populate_keys_from_metadata_server()
@@ -332,6 +358,7 @@ class Provider(object):
         self.storage_class_header = header_info_map[STORAGE_CLASS_HEADER_KEY]
         self.version_id = header_info_map[VERSION_ID_HEADER_KEY]
         self.mfa_header = header_info_map[MFA_HEADER_KEY]
+        self.restore_header = header_info_map[RESTORE_HEADER_KEY]
 
     def configure_errors(self):
         error_map = self.ErrorMap[self.name]
