@@ -1,10 +1,10 @@
-import os, sys, time, traceback
-import smtplib
+import os
+import sys
 from boto.utils import ShellCommand, get_ts
 import boto
 import boto.utils
 
-class ScriptBase:
+class ScriptBase(object):
 
     def __init__(self, config_file=None):
         self.instance_id = boto.config.get('Instance', 'instance-id', 'default')
@@ -27,8 +27,8 @@ class ScriptBase:
         if os.path.ismount(path):
             self.run('umount %s' % path)
 
-    def run(self, command, notify=True, exit_on_error=False):
-        self.last_command = ShellCommand(command)
+    def run(self, command, notify=True, exit_on_error=False, cwd=None):
+        self.last_command = ShellCommand(command, cwd=cwd)
         if self.last_command.status != 0:
             boto.log.error('Error running command: "%s". Output: "%s"' % (command, self.last_command.output))
             if notify:
@@ -41,4 +41,4 @@ class ScriptBase:
 
     def main(self):
         pass
-        
+
