@@ -71,8 +71,9 @@ class MWSTestCase(unittest.TestCase):
         response = self.mws.get_product_categories_for_asin(
             MarketplaceId=self.marketplace_id,
             ASIN=asin)
-        result = response._result
-        self.assertTrue(int(result.Self.ProductCategoryId) == 21)
+        self.assertTrue(len(response._result.Self) == 2)
+        categoryids = [x.ProductCategoryId for x in response._result.Self]
+        self.assertSequenceEqual(categoryids, ['285856', '21'])
 
     @unittest.skipUnless(simple and isolator, "skipping simple test")
     def test_list_matching_products(self):
