@@ -100,6 +100,17 @@ class S3MultiPartUploadTest(unittest.TestCase):
             self.assertEqual(lmpu.id, ompu.id)
         self.assertEqual(0, len(mpus))
 
+    def test_get_all_multipart_uploads(self):
+        key1 = 'a'
+        key2 = 'b/c'
+        mpu1 = self.bucket.initiate_multipart_upload(key1)
+        mpu2 = self.bucket.initiate_multipart_upload(key2)
+        rs = self.bucket.get_all_multipart_uploads(prefix='b/', delimiter='/')
+        for lmpu in rs:
+            # only expect upload for key2 (mpu2) returned
+            self.assertEqual(lmpu.key_name, mpu2.key_name)
+            self.assertEqual(lmpu.id, mpu2.id)
+
     def test_four_part_file(self):
         key_name = "k"
         contents = "01234567890123456789"
